from .Base import Base


class Customer(Base):
    pass
